| Title: | ICES Rmarkdown tools |
|---|---|
| Description: | A collection of rmarkdown and pandoc versions of various ICES templates can be found here. |
| Authors: | Iago Mosqueira [cre] (ORCID: <https://orcid.org/0000-0002-3252-0591>), Colin Millar [aut] |
| Maintainer: | Iago Mosqueira <[email protected]> |
| License: | EUPL |
| Version: | 0.1.2 |
| Built: | 2026-05-22 08:53:17 UTC |
| Source: | https://github.com/ices-tools-prod/icesdown |
Coercing FLQuant(s) into flextable
## S4 method for signature 'FLQuant' as_flextable(x) ## S4 method for signature 'FLQuants' as_flextable(x)## S4 method for signature 'FLQuant' as_flextable(x) ## S4 method for signature 'FLQuants' as_flextable(x)
x |
Object to transform, of class 'FLQuant' or 'FLQuants' |
data(ple4) as_flextable(catch(ple4)) as_flextable(catch.n(ple4)) as_flextable(metrics(ple4))data(ple4) as_flextable(catch(ple4)) as_flextable(catch.n(ple4)) as_flextable(metrics(ple4))
Template for Rmarkdown version of a stock assessment template
stockReport(...)stockReport(...)
... |
Any arguments to pass to bookdown::markdown_document2 |
A document configuration, of class rmarkdown_output_format.